import { WindowInfo } from "@v-act/vjs.framework.extension.platform.data.manager.runtime.info";
import { ScopeManager } from "@v-act/vjs.framework.extension.platform.interface.scope";
import { WidgetContext } from "@v-act/vjs.framework.extension.platform.services.view.widget.common.context";
let permissionPool = {};
let getScopeContext = function() {
  let scopeId = ScopeManager.getCurrentScopeId() || "null";
  let scopeContext = permissionPool[scopeId];
  if (!scopeContext) {
    scopeContext = permissionPool[scopeId] = {};
  }
  return scopeContext;
};
let getPermissionContext = function() {
  let scopeContext = getScopeContext();
  let permission = scopeContext["permission"];
  if (!permission) {
    permission = scopeContext["permission"] = {};
  }
  return permission;
};
let addPermission = function(widgetId, hasPermission2) {
  let permissionList = getPermissionContext();
  permissionList[widgetId] = hasPermission2;
};
let setPermission = function(permission) {
  let permissionList = getPermissionContext();
  for (let key in permission) {
    permissionList[key] = permission[key];
  }
};
let hasPermission = function(widgetId, propertyName) {
  let permissionList = getPermissionContext();
  if (permissionList.hasOwnProperty(widgetId)) {
    let info = permissionList[widgetId];
    if (info) {
      if (typeof info == "object") {
        if (info.hasOwnProperty("_hasPermission")) {
          return info["_hasPermission"];
        } else {
          switch (propertyName) {
            case "setEnabled":
            case "getEnabled":
              if (info.hasOwnProperty("Enabled")) {
                return info["Enabled"];
              }
              break;
            case "setVisible":
            case "getVisible":
              if (info.hasOwnProperty("Visible")) {
                return info["Visible"];
              }
              break;
            case "setReadOnly":
            case "getReadOnly":
              if (info.hasOwnProperty("ReadOnly")) {
                return !info["ReadOnly"];
              }
              break;
            default:
              return true;
          }
          return true;
        }
      }
    }
    return info;
  } else {
    return true;
  }
};
let initViewLibPermssion = function(mappings, allRelationStr, componentCode, windowCode) {
  if (allRelationStr != null && allRelationStr != "") {
    let allRelations = JSON.parse(allRelationStr);
    let aRs = {};
    if (allRelations) {
      for (let pId in allRelations) {
        if (!allRelations.hasOwnProperty(pId))
          continue;
        let childInfos = allRelations[pId];
        if (!childInfos || childInfos.length < 1)
          continue;
        for (let i2 = 0; i2 < childInfos.length; i2++) {
          let childInfo = childInfos[i2];
          childInfo.type;
          let code = childInfo.code;
          WidgetContext.put(code, "ProxyWidgetId", childInfo.proxyWidgetId);
          WidgetContext.put(code, "WidgetType", childInfo.type);
          aRs[code] = pId;
        }
      }
    }
    let widgetPermission = WindowInfo.getWidgetPermission(componentCode, windowCode);
    if (widgetPermission && widgetPermission.edit) {
      let wp = widgetPermission.edit;
      for (let wId in wp) {
        let modifyProperty = wp[wId];
        if (aRs[wId]) {
          let parentId = aRs[wId];
          let parentProperty = mappings[parentId];
          if (!parentProperty)
            continue;
          let childPropertys = {};
          switch (parentProperty._$WidgetType) {
            case "JGDataGrid":
            case "JGTreeGrid":
              var fields = parentProperty.fields;
              if (!fields || fields.length < 1)
                continue;
              for (var i = 0; i < fields.length; i++) {
                var fieldProperty = fields[i];
                var columnId = fieldProperty.columnId;
                if (columnId == wId) {
                  if (modifyProperty.hasOwnProperty("ReadOnly")) {
                    fieldProperty.canEdit = !modifyProperty.ReadOnly;
                  }
                  if (modifyProperty.hasOwnProperty("Enabled")) {
                    fieldProperty.disabled = !modifyProperty.Enabled;
                  }
                  if (modifyProperty.hasOwnProperty("Visible")) {
                    fieldProperty.showIf = modifyProperty.Visible + "";
                  }
                  childPropertys[fieldProperty.columnId] = fieldProperty;
                }
              }
              break;
            case "JGTabControl":
              var tabs = parentProperty.tabs;
              if (!tabs || tabs.length < 1)
                continue;
              for (var i = 0; i < tabs.length; i++) {
                var tabProperty = tabs[i];
                childPropertys[tabProperty.id] = tabProperty;
              }
              break;
          }
          let childProperty = childPropertys[wId];
          if (!childProperty)
            continue;
          for (let mP in modifyProperty) {
            if (!modifyProperty.hasOwnProperty(mP))
              continue;
            if (mP == "_hasPermission") {
              childProperty["Enabled"] = modifyProperty[mP];
            } else {
              childProperty[mP] = modifyProperty[mP];
            }
            childProperty[mP] = modifyProperty[mP];
          }
        } else {
          let parentProperty = mappings[wId];
          if (!parentProperty)
            continue;
          for (let mP in modifyProperty) {
            if (!modifyProperty.hasOwnProperty(mP))
              continue;
            if (mP == "_hasPermission") {
              parentProperty["Enabled"] = modifyProperty[mP];
            } else {
              parentProperty[mP] = modifyProperty[mP];
            }
          }
        }
      }
    }
  }
};
var Permission = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  [Symbol.toStringTag]: "Module",
  addPermission,
  hasPermission,
  initViewLibPermssion,
  setPermission
});
export { Permission };
